@@ -4,8 +4,7 @@
 #' the similarly named functions in the httr package and can be used as
 #' drop-in replacements for them.
 #'
-#' \code{GET}
-#' checks the cache before making an HTTP request, and if there is a cache
+#' `GET` checks the cache before making an HTTP request, and if there is a cache
 #' miss, it sets the response from the request into the cache for future
 #' requests. The other verbs, assuming a more or less RESTful API, would be
 #' assumed to modify server state, and thus they should trigger cache
@@ -14,18 +13,18 @@
 #'
 #' @param url character URL of the request
 #' @param ... additional arguments passed to the httr functions
-#' @param drop For \code{PUT}, \code{PATCH}, \code{POST}, and \code{DELETE},
+#' @param drop For `PUT`, `PATCH`, `POST`, and `DELETE`,
 #' code to be executed after the request. This is intended to be for supplying
-#' cache-invalidation logic. By default, \code{POST} drops cache only for
-#' the specified \code{url} (i.e. \code{\link{dropOnly}}), while the other
+#' cache-invalidation logic. By default, `POST` drops cache only for
+#' the specified `url` (i.e. [dropOnly()]), while the other
 #' verbs drop cache for the request URL and for any URLs nested below it
-#' (i.e. \code{\link{dropCache}}).
+#' (i.e. [dropCache()]).
 #' @return The corresponding httr response object, potentially read from cache
 #' @importFrom httr GET
 #' @importFrom digest digest
 #' @aliases GET PUT POST PATCH DELETE
 #' @name cached-http-verbs
-#' @seealso \code{\link{dropCache}} \code{\link{cachedPOST}} \code{\link{cachedDownload}}
+#' @seealso [dropCache()] [cachedPOST()] [cachedDownload()]
 #' @export
 GET <- function (url, ...) {
     validateURL(url)
@@ -73,10 +72,10 @@ POST <- function (url, ..., drop=dropOnly(url)) {
 #' Some APIs have resources where a POST is used to send a command that returns
 #' content and doesn't modify state. In this case, it's more like a GET. This
 #' may occur where one might normally GET but the request URI would be too long
-#' for the server to accept. \code{cachedPOST} thus behaves more like
-#' \code{GET}, checking for a cached response before performing the request and
+#' for the server to accept. `cachedPOST` thus behaves more like
+#' `GET`, checking for a cached response before performing the request and
 #' setting cache if the request is successful. It does no cache dropping, unlike
-#' \code{\link[httpcache]{POST}}.
+#' [httpcache::POST()].
 #' @param url character URL of the request
 #' @param ... additional arguments passed to the httr functions
 #' @return The corresponding httr response object, potentially read from cache
@@ -127,6 +126,6 @@ validateURL <- function (url) {
     ## Make sure it's a string. Give a useful error if not.
     if (!is.character(url)) {
         ## Basic input validation
-        stop("Invalid URL: ", deparse(url)[1])
+        stop("Invalid URL: ", deparse(url, control=NULL)[1])
     }
 }
